<?php

/**
 * @file
 * Contains Drupal\toc_api\Entity\TocType.
 */

namespace Drupal\toc_api\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\toc_api\TocTypeInterface;

/**
 * Defines the TOC type entity.
 *
 * @ConfigEntityType(
 *   id = "toc_type",
 *   label = @Translation("TOC type"),
 *   admin_permission = "administer toc_types",
 *   handlers = {
 *     "access" = "Drupal\toc_api\TocTypeAccessControlHandler",
 *     "list_builder" = "Drupal\toc_api\TocTypeListBuilder",
 *     "form" = {
 *       "add" = "Drupal\toc_api\TocTypeForm",
 *       "edit" = "Drupal\toc_api\TocTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   links = {
 *     "edit-form" = "/admin/structure/toc/manage/{toc_type}",
 *     "delete-form" = "/admin/structure/toc/manage/{toc_type}/delete"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "options",
 *   }
 * )
 */
class TocType extends ConfigEntityBase implements TocTypeInterface {

  /**
   * The TOC type ID.
   *
   * @var string
   */
  public $id;

  /**
   * The TOC type UUID.
   *
   * @var string
   */
  public $uuid;

  /**
   * The TOC type label.
   *
   * @var string
   */
  public $label;

  /**
   * The TOC type options.
   *
   * @var array
   */
  public $options;

}
